@@ -18,8 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solver interface for `ECOS <https://github.com/embotech/ecos>`__.
+"""Solver interface for `ECOS <https://github.com/embotech/ecos>`__.
 
 ECOS is an interior-point solver for convex second-order cone programs (SOCPs).
 designed specifically for embedded applications. ECOS is written in low
@@ -66,20 +65,7 @@ def ecos_solve_problem(
     verbose: bool = False,
     **kwargs,
 ) -> Solution:
-    """
-    Solve a Quadratic Program defined as:
-
-    .. math::
-
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b
-        \\end{array}\\end{split}
-
-    using `ECOS <https://github.com/embotech/ecos>`_.
+    """Solve a quadratic program using ECOS.
 
     Parameters
     ----------
@@ -159,12 +145,12 @@ def ecos_solve_problem(
     else:
         result = solve(c_socp, G_socp, h_socp, dims, **kwargs)
     flag = result["info"]["exitFlag"]
+    solution = Solution(problem)
+    solution.extras = result["info"]
     if flag != 0:
         meaning = __exit_flag_meaning__.get(flag, "unknown exit flag")
         warnings.warn(f"ECOS returned exit flag {flag} ({meaning})")
-        return Solution(problem)
-
-    solution = Solution(problem)
+        return solution
     solution.x = result["x"][:-1]
     if A is not None:
         solution.y = result["y"]
@@ -173,7 +159,6 @@ def ecos_solve_problem(
         z, z_box = split_dual_linear_box(z_ecos, lb, ub)
         solution.z = z
         solution.z_box = z_box
-    solution.extras = result["info"]
     return solution
 
 
@@ -190,20 +175,21 @@ def ecos_solve_qp(
     verbose: bool = False,
     **kwargs,
 ) -> Optional[np.ndarray]:
-    """
-    Solve a Quadratic Program defined as:
+    r"""Solve a quadratic program using ECOS.
+
+    The quadratic program is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
+        \begin{split}\begin{array}{ll}
+            \underset{x}{\mbox{minimize}} &
+                \frac{1}{2} x^T P x + q^T x \\
+            \mbox{subject to}
+                & G x \leq h                \\
                 & A x = b
-        \\end{array}\\end{split}
+        \end{array}\end{split}
 
-    using `ECOS <https://github.com/embotech/ecos>`_.
+    It is solved using `ECOS <https://github.com/embotech/ecos>`__.
 
     Parameters
     ----------
