@@ -18,9 +18,9 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solver interface for `ProxQP
-<https://github.com/Simple-Robotics/proxsuite#proxqp>`__.
+"""Solver interface for `ProxQP`_.
+
+.. _ProxQP: https://github.com/Simple-Robotics/proxsuite#proxqp
 
 ProxQP is the QP solver from ProxSuite, a collection of open-source solvers
 rooted in revisited primal-dual proximal algorithms. If you use ProxQP in some
@@ -33,13 +33,13 @@ import numpy as np
 import scipy.sparse as spa
 from proxsuite import proxqp
 
+from ..exceptions import ParamError, ProblemError
 from ..problem import Problem
 from ..solution import Solution
 
 
 def __combine_inequalities(G, h, lb, ub, n: int, use_csc: bool):
-    """
-    Combine linear and box inequalities for ProxQP.
+    """Combine linear and box inequalities for ProxQP.
 
     Parameters
     ----------
@@ -60,6 +60,11 @@ def __combine_inequalities(G, h, lb, ub, n: int, use_csc: bool):
     -------
     :
         Linear inequality matrices :math:`C`, :math:`l` and :math:`u`.
+
+    Raises
+    ------
+    ProblemError
+        If the inequality matrix and vector are not consistent.
     """
     if lb is None and ub is None:
         C_prox = G
@@ -82,13 +87,12 @@ def __combine_inequalities(G, h, lb, ub, n: int, use_csc: bool):
         l_prox = np.hstack((np.full(h.shape, -np.infty), lb))
         u_prox = np.hstack((h, ub))
     else:  # G is not None and h is None
-        raise ValueError("Inconsistent inequalities: G is set but h is None")
+        raise ProblemError("Inconsistent inequalities: G is set but h is None")
     return C_prox, u_prox, l_prox
 
 
 def __select_backend(backend: Optional[str], use_csc: bool):
-    """
-    Select backend function for ProxQP.
+    """Select backend function for ProxQP.
 
     Parameters
     ----------
@@ -102,6 +106,11 @@ def __select_backend(backend: Optional[str], use_csc: bool):
     -------
     :
         Backend solve function.
+
+    Raises
+    ------
+    ParamError
+        If the required backend is not a valid ProxQP backend.
     """
     if backend is None:
         return proxqp.sparse.solve if use_csc else proxqp.dense.solve
@@ -109,7 +118,7 @@ def __select_backend(backend: Optional[str], use_csc: bool):
         return proxqp.dense.solve
     if backend == "sparse":
         return proxqp.sparse.solve
-    raise ValueError(f'Unknown ProxQP backend "{backend}')
+    raise ParamError(f'Unknown ProxQP backend "{backend}')
 
 
 def proxqp_solve_problem(
@@ -119,9 +128,7 @@ def proxqp_solve_problem(
     backend: Optional[str] = None,
     **kwargs,
 ) -> Solution:
-    """
-    Solve a Quadratic Program using `ProxQP
-    <https://github.com/Simple-Robotics/proxsuite>`__.
+    """Solve a quadratic program using ProxQP.
 
     Parameters
     ----------
@@ -140,6 +147,12 @@ def proxqp_solve_problem(
     :
         Solution to the QP returned by the solver.
 
+    Raises
+    ------
+    ParamError
+        If a warm-start value is given both in `initvals` and the `x` keyword
+        argument.
+
     Notes
     -----
     All other keyword arguments are forwarded as options to ProxQP. For
@@ -188,7 +201,7 @@ def proxqp_solve_problem(
     """
     if initvals is not None:
         if "x" in kwargs:
-            raise ValueError(
+            raise ParamError(
                 "Warm-start value specified in both `initvals` and `x` kwargs"
             )
         kwargs["x"] = initvals
@@ -200,8 +213,8 @@ def proxqp_solve_problem(
         or (A is not None and not isinstance(A, np.ndarray))
     )
     C_prox, u_prox, l_prox = __combine_inequalities(G, h, lb, ub, n, use_csc)
-    solve_function = __select_backend(backend, use_csc)
-    result = solve_function(
+    solve = __select_backend(backend, use_csc)
+    result = solve(
         P,
         q,
         A,
@@ -240,21 +253,23 @@ def proxqp_solve_qp(
     backend: Optional[str] = None,
     **kwargs,
 ) -> Optional[np.ndarray]:
-    """
-    Solve a Quadratic Program defined as:
+    r"""Solve a quadratic program using ProxQP.
+
+    The quadratic program is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-        \\underset{\\mbox{minimize}}{x} &
-            \\frac{1}{2} x^T P x + q^T x \\\\
-        \\mbox{subject to}
-            & G x \\leq h                \\\\
-            & A x = b                    \\\\
-            & lb \\leq x \\leq ub
-        \\end{array}\\end{split}
+        \begin{split}\begin{array}{ll}
+        \underset{\mbox{minimize}}{x} &
+            \frac{1}{2} x^T P x + q^T x \\
+        \mbox{subject to}
+            & G x \leq h                \\
+            & A x = b                   \\
+            & lb \leq x \leq ub
+        \end{array}\end{split}
 
-    using `ProxQP <https://github.com/Simple-Robotics/proxsuite>`__.
+    It is solved using `ProxQP
+    <https://github.com/Simple-Robotics/proxsuite#proxqp>`__.
 
     Parameters
     ----------
