@@ -18,6 +18,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
+"""Unit tests for ECOS."""
+
 import unittest
 import warnings
 
@@ -27,10 +29,7 @@ try:
     from qpsolvers.solvers.ecos_ import ecos_solve_qp
 
     class TestECOS(unittest.TestCase):
-
-        """
-        Tests specific to ECOS.
-        """
+        """Tests specific to ECOS."""
 
         def test_problem(self):
             problem = get_sd3310_problem()
