@@ -18,6 +18,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
+"""Unit tests for MOSEK."""
+
 import unittest
 import warnings
 
@@ -27,10 +29,7 @@ try:
     from qpsolvers.solvers.mosek_ import mosek_solve_qp
 
     class TestMOSEK(unittest.TestCase):
-
-        """
-        Tests specific to MOSEK.
-        """
+        """Tests specific to MOSEK."""
 
         def test_problem(self):
             problem = get_sd3310_problem()
