@@ -18,24 +18,23 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
+"""Unit tests for ProxQP."""
+
 import unittest
 import warnings
 
+from qpsolvers.exceptions import ParamError, ProblemError
+
 from .problems import get_sd3310_problem
 
 try:
     from qpsolvers.solvers.proxqp_ import proxqp_solve_qp
 
     class TestProxQP(unittest.TestCase):
-
-        """
-        Test fixture specific to the ProxQP solver.
-        """
+        """Test fixture specific to the ProxQP solver."""
 
         def test_dense_backend(self):
-            """
-            Try the dense backend.
-            """
+            """Try the dense backend."""
             problem = get_sd3310_problem()
             proxqp_solve_qp(
                 problem.P,
@@ -48,9 +47,7 @@ try:
             )
 
         def test_sparse_backend(self):
-            """
-            Try the sparse backend.
-            """
+            """Try the sparse backend."""
             problem = get_sd3310_problem()
             proxqp_solve_qp(
                 problem.P,
@@ -63,11 +60,9 @@ try:
             )
 
         def test_invalid_backend(self):
-            """
-            Exception raised when asking for an invalid backend.
-            """
+            """Exception raised when asking for an invalid backend."""
             problem = get_sd3310_problem()
-            with self.assertRaises(ValueError):
+            with self.assertRaises(ParamError):
                 proxqp_solve_qp(
                     problem.P,
                     problem.q,
@@ -79,12 +74,9 @@ try:
                 )
 
         def test_double_warm_start(self):
-            """
-            Raise an exception when two warm-start values are provided at the
-            same time.
-            """
+            """Exception when two warm-start values are provided."""
             problem = get_sd3310_problem()
-            with self.assertRaises(ValueError):
+            with self.assertRaises(ParamError):
                 proxqp_solve_qp(
                     problem.P,
                     problem.q,
@@ -97,13 +89,14 @@ try:
                 )
 
         def test_invalid_inequalities(self):
-            """
+            """Check for inconsistent parameters.
+
             Raise an exception in an implementation-dependent inconsistent set
             of parameters. This may happen when :func:`proxqp_solve_qp` it is
             called directly.
             """
             problem = get_sd3310_problem()
-            with self.assertRaises(ValueError):
+            with self.assertRaises(ProblemError):
                 proxqp_solve_qp(
                     problem.P,
                     problem.q,
