@@ -18,6 +18,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
+"""Unit tests for quadprog."""
+
 import unittest
 import warnings
 
@@ -26,28 +28,25 @@ import scipy.sparse as spa
 
 from qpsolvers import ProblemError
 
+from qpsolvers.exceptions import ProblemError
+
 from .problems import get_sd3310_problem
 
 try:
     from qpsolvers.solvers.quadprog_ import quadprog_solve_qp
 
     class TestQuadprog(unittest.TestCase):
-
-        """
-        Test fixture for the quadprog solver.
-        """
+        """Test fixture for the quadprog solver."""
 
         def setUp(self):
-            """
-            Prepare test fixture.
-            """
+            """Prepare test fixture."""
             warnings.simplefilter("ignore", category=UserWarning)
 
         def test_non_psd_cost(self):
             problem = get_sd3310_problem()
             P, q, G, h, A, b, _, _ = problem.unpack()
             P -= np.eye(3)
-            with self.assertRaises(ValueError):
+            with self.assertRaises(ProblemError):
                 quadprog_solve_qp(P, q, G, h, A, b)
 
         def test_quadprog_value_error(self):
@@ -57,9 +56,7 @@ try:
             self.assertIsNone(quadprog_solve_qp(P, q, G, h, A, b))
 
         def test_not_sparse(self):
-            """
-            Raise a ProblemError on sparse problems.
-            """
+            """Raise a ProblemError on sparse problems."""
             problem = get_sd3310_problem()
             P, q, G, h, A, b, _, _ = problem.unpack()
             P = spa.csc_matrix(P)
