@@ -18,9 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Tests for the `solve_qp` function.
-"""
+"""Unit tests for the `solve_qp` function."""
 
 import unittest
 import warnings
@@ -32,13 +30,13 @@ from numpy.linalg import norm
 from scipy.sparse import csc_matrix
 
 from qpsolvers import (
+    NoSolverSelected,
+    ProblemError,
+    SolverNotFound,
     available_solvers,
-    dense_solvers,
     solve_qp,
-    solve_safer_qp,
     sparse_solvers,
 )
-from qpsolvers.exceptions import NoSolverSelected, SolverNotFound
 
 from .problems import get_qpmad_demo_problem
 
@@ -46,7 +44,7 @@ from .problems import get_qpmad_demo_problem
 # achieved by some solvers. Here are the behaviors observed as of March 2022.
 # Unit tests only cover solvers that raise successfully:
 behavior_on_unbounded = {
-    "raise_value_error": ["cvxopt", "ecos", "quadprog", "scs"],
+    "raise": ["cvxopt", "ecos", "quadprog", "scs"],
     "return_crazy_solution": ["qpoases"],
     "return_none": ["osqp"],
 }
@@ -54,8 +52,7 @@ behavior_on_unbounded = {
 
 class TestSolveQP(unittest.TestCase):
 
-    """
-    Test fixture for a variety of quadratic programs.
+    """Test fixture for a variety of quadratic programs.
 
     Solver-specific tests are implemented in static methods called
     ``get_test_{foo}`` that return the test function for a given solver. The
@@ -64,15 +61,12 @@ class TestSolveQP(unittest.TestCase):
     """
 
     def setUp(self):
-        """
-        Prepare test fixture.
-        """
+        """Prepare test fixture."""
         warnings.simplefilter("ignore", category=DeprecationWarning)
         warnings.simplefilter("ignore", category=UserWarning)
 
     def get_dense_problem(self):
-        """
-        Get dense problem as a sextuple of values to unpack.
+        """Get dense problem as a sextuple of values to unpack.
 
         Returns
         -------
@@ -99,8 +93,7 @@ class TestSolveQP(unittest.TestCase):
         return P, q, G, h, A, b
 
     def get_sparse_problem(self):
-        """
-        Get sparse problem as a quadruplet of values to unpack.
+        """Get sparse problem as a quadruplet of values to unpack.
 
         Returns
         -------
@@ -125,25 +118,20 @@ class TestSolveQP(unittest.TestCase):
         return P, q, G, h
 
     def test_no_solver_selected(self):
-        """
-        Check that NoSolverSelected is raised when applicable.
-        """
+        """Check that NoSolverSelected is raised when applicable."""
         P, q, G, h, A, b = self.get_dense_problem()
         with self.assertRaises(NoSolverSelected):
             solve_qp(P, q, G, h, A, b, solver=None)
 
     def test_solver_not_found(self):
-        """
-        Check that SolverNotFound is raised when the solver does not exist.
-        """
+        """SolverNotFound is raised when the solver does not exist."""
         P, q, G, h, A, b = self.get_dense_problem()
         with self.assertRaises(SolverNotFound):
             solve_qp(P, q, G, h, A, b, solver="ideal")
 
     @staticmethod
     def get_test(solver):
-        """
-        Get test function for a given solver.
+        """Get test function for a given solver.
 
         Parameters
         ----------
@@ -159,7 +147,7 @@ class TestSolveQP(unittest.TestCase):
         def test(self):
             P, q, G, h, A, b = self.get_dense_problem()
             x = solve_qp(P, q, G, h, A, b, solver=solver)
-            x_sp = solve_qp(P, q, G, h, A, b, solver=solver, sym_proj=True)
+            x_sp = solve_qp(P, q, G, h, A, b, solver=solver)
             self.assertIsNotNone(x)
             self.assertIsNotNone(x_sp)
             known_solution = array([0.30769231, -0.69230769, 1.38461538])
@@ -192,9 +180,10 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_all_shapes(solver):
-        """
-        Get test function for a given solver. This variant tries all possible
-        shapes for matrix and vector parameters.
+        """Get test function for a given solver.
+
+        This variant tries all possible shapes for matrix and vector
+        parameters.
 
         Parameters
         ----------
@@ -273,8 +262,9 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_bounds(solver):
-        """
-        Get test function for a given solver. This variant adds vector bounds.
+        """Get test function for a given solver.
+
+        This variant adds vector bounds.
 
         Parameters
         ----------
@@ -316,9 +306,9 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_no_cons(solver):
-        """
-        Get test function for a given solver. In this variant, there is
-        no equality nor inequality constraint.
+        """Get test function for a given solver.
+
+        In this variant, there is no equality nor inequality constraint.
 
         Parameters
         ----------
@@ -349,9 +339,9 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_no_eq(solver):
-        """
-        Get test function for a given solver. In this variant, there is
-        no equality constraint.
+        """Get test function for a given solver.
+
+        In this variant, there is no equality constraint.
 
         Parameters
         ----------
@@ -392,9 +382,9 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_no_ineq(solver):
-        """
-        Get test function for a given solver. In this variant, there is
-        no inequality constraint.
+        """Get test function for a given solver.
+
+        In this variant, there is no inequality constraint.
 
         Parameters
         ----------
@@ -432,9 +422,9 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_one_ineq(solver):
-        """
-        Get test function for a given solver. In this variant, there is
-        only one inequality constraint.
+        """Get test function for a given solver.
+
+        In this variant, there is only one inequality constraint.
 
         Parameters
         ----------
@@ -483,55 +473,11 @@ class TestSolveQP(unittest.TestCase):
 
         return test
 
-    @staticmethod
-    def get_test_safer(solver):
-        """
-        Get test function for a given solver.
-
-        Parameters
-        ----------
-        solver : string
-            Name of the solver to test.
-
-        Returns
-        -------
-        test : function
-            Test function for that solver.
-        """
-
-        def test(self):
-            P, q, G, h, _, _ = self.get_dense_problem()
-            if solver not in dense_solvers:
-                with self.assertRaises(NotImplementedError):
-                    solve_safer_qp(P, q, G, h, sr=1e-4, solver=solver)
-                return
-            x = solve_safer_qp(P, q, G, h, sr=1e-4, solver=solver)
-            self.assertIsNotNone(x)
-            known_solution = array([-0.49021915, -1.57749935, -0.66477954])
-            sol_tolerance = (
-                2e-3
-                if solver == "proxqp"  # test params not applied
-                else 1e-4
-                if solver in ["ecos", "scs"]
-                else 1e-6
-            )
-            ineq_tolerance = (
-                1e-7
-                if solver == "scs"
-                else 1e-6
-                if solver == "proxqp"
-                else 1e-10
-            )
-            self.assertLess(norm(x - known_solution), sol_tolerance)
-            self.assertLess(max(dot(G, x) - h), ineq_tolerance)
-
-        return test
-
     @staticmethod
     def get_test_sparse(solver):
-        """
-        Get test function for a given solver. This variant tests a sparse
-        problem.
+        """Get test function for a given solver.
+
+        This variant tests a sparse problem.
 
         Parameters
         ----------
@@ -552,10 +498,12 @@ class TestSolveQP(unittest.TestCase):
             sol_tolerance = (
                 5e-3
                 if solver == "cvxopt"
+                else 2e-3
+                if solver == "osqp"
                 else 1e-3
                 if solver == "gurobi"
                 else 5e-4
-                if solver == "osqp"
+                if solver == "clarabel"
                 else 1e-4
                 if solver == "scs"
                 else 2e-5
@@ -580,9 +528,10 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_sparse_bounds(solver):
-        """
-        Get test function for a given solver. This variant tests a sparse
-        problem with additional vector lower and upper bounds.
+        """Get test function for a given solver.
+
+        This variant tests a sparse problem with additional vector lower and
+        upper bounds.
 
         Parameters
         ----------
@@ -621,9 +570,10 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_sparse_unfeasible(solver):
-        """
-        Get test function for a given solver. This variant tests an unfeasible
-        sparse problem with additional vector lower and upper bounds.
+        """Get test function for a given solver.
+
+        This variant tests an unfeasible sparse problem with additional vector
+        lower and upper bounds.
 
         Parameters
         ----------
@@ -651,8 +601,9 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_warmstart(solver):
-        """
-        Get test function for a given solver. This variant warm starts.
+        """Get test function for a given solver.
+
+        This variant warm starts.
 
         Parameters
         ----------
@@ -709,8 +660,7 @@ class TestSolveQP(unittest.TestCase):
 
     @staticmethod
     def get_test_raise_on_unbounded_below(solver):
-        """
-        Check that a ValueError is raised when the problem is unbounded below.
+        """ValueError is raised when the problem is unbounded below.
 
         Parameters
         ----------
@@ -736,15 +686,14 @@ class TestSolveQP(unittest.TestCase):
             P = dot(v.reshape(4, 1), v.reshape(1, 4))
             q = array([-1.0, -2, 0, 3e-4])
             # q is in the nullspace of P, so the problem is unbounded below
-            with self.assertRaises(ValueError):
+            with self.assertRaises(ProblemError):
                 solve_qp(P, q, solver=solver)
 
         return test
 
     @staticmethod
     def get_test_qpmad_demo(solver):
-        """
-        Get test function for a given solver.
+        """Get test function for a given solver.
 
         Parameters
         ----------
@@ -839,11 +788,6 @@ for solver in available_solvers:
         f"test_one_ineq_{solver}",
         TestSolveQP.get_test_one_ineq(solver),
     )
-    setattr(
-        TestSolveQP,
-        f"test_safer_{solver}",
-        TestSolveQP.get_test_safer(solver),
-    )
     if solver in sparse_solvers:
         setattr(
             TestSolveQP,
@@ -865,7 +809,7 @@ for solver in available_solvers:
         f"test_warmstart_{solver}",
         TestSolveQP.get_test_warmstart(solver),
     )
-    if solver in behavior_on_unbounded["raise_value_error"]:
+    if solver in behavior_on_unbounded["raise"]:
         setattr(
             TestSolveQP,
             f"test_raise_on_unbounded_below_{solver}",
